# stat-basic-dist package

This a statistical package to calculate distribution mean, stdev and visualize data density function.

# installation

```
$ pip install stat-basic-dist
```

## Examples

```
from stat_basic_dist import Binomial, Gaussian
```

## TODOS

- Add more distributions
- Add flexibility to read more data format
- Add tests
- Add more visualization options
